==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.warrantycoverage_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.warrantycoverage_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link WarrantyCoverage }
     * 
     */
    public WarrantyCoverage createWarrantyCoverage() {
        return new WarrantyCoverage();
    }

    /**
     * Create an instance of {@link EquipmentWarranty }
     * 
     */
    public EquipmentWarranty createEquipmentWarranty() {
        return new EquipmentWarranty();
    }

    /**
     * Create an instance of {@link CoverageByDate }
     * 
     */
    public CoverageByDate createCoverageByDate() {
        return new CoverageByDate();
    }

    /**
     * Create an instance of {@link CoverageByUsage }
     * 
     */
    public CoverageByUsage createCoverageByUsage() {
        return new CoverageByUsage();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.warrantycoverage_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.warrantycoverage_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link WarrantyCoverage }
     * 
     * @return
     *     the new instance of {@link WarrantyCoverage }
     */
    public WarrantyCoverage createWarrantyCoverage() {
        return new WarrantyCoverage();
    }

    /**
     * Create an instance of {@link EquipmentWarranty }
     * 
     * @return
     *     the new instance of {@link EquipmentWarranty }
     */
    public EquipmentWarranty createEquipmentWarranty() {
        return new EquipmentWarranty();
    }

    /**
     * Create an instance of {@link CoverageByDate }
     * 
     * @return
     *     the new instance of {@link CoverageByDate }
     */
    public CoverageByDate createCoverageByDate() {
        return new CoverageByDate();
    }

    /**
     * Create an instance of {@link CoverageByUsage }
     * 
     * @return
     *     the new instance of {@link CoverageByUsage }
     */
    public CoverageByUsage createCoverageByUsage() {
        return new CoverageByUsage();
    }

}
